import setuptools

setuptools.setup(
    name="test_Gna",
    version="1.1",
    license='MIT',
    author="Gna",
    author_email="luckyrookie@khu.ac.kr",
    description="test.",
    long_description=open('README.md').read(),
    url="https://github.com/GyeongahNa",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
)